import { Message, PermissionFlags, Snowflake } from 'discord.js';
/**
 * Set a name for the Command
 * @method Name
 * @param name {String} The name of the command
 * @returns {ClassDecorator}
 */
export declare function Name(name: string): ClassDecorator;
/**
 * Only allow the command to be executed in a guild channel
 * @method GuildOnly
 * @returns {ClassDecorator}
 */
export declare function Only(...types: string[]): ClassDecorator;
/**
 * This extends the default command verifier and the given function runs
 * BEFORE any other part of the verifier runs
 * @method Verify
 * @param func {Function} The custom verifier part you want to use
 * @returns {ClassDecorator}
 */
export declare function Verify(func: (msg: Message, client?: any) => boolean | Promise<boolean>): ClassDecorator;
/**
 * Throttles commands to be only usable for x times per y seconds
 * @method Throttle
 * @param interval {Number} The time in seconds
 * @param times {Number} How often the command can be executed in X seconds
 * @param [all] {Boolean} Weather to throttle all (true) users or exclude the owner
 * @returns {ClassDecorator}
 */
export declare function Throttle(interval: number, times: number, all?: boolean): ClassDecorator;
/**
 * Set the aliases for a command
 * @param aliases {String[]} The aliases to apply
 * @returns {ClassDecorator}
 */
export declare function Alias(...aliases: string[]): ClassDecorator;
export declare function UserPermissions(...perms: PermissionFlags[]): ClassDecorator;
export declare function Restricted(data: {
    roles: Snowflake[];
    users: Snowflake[];
}): ClassDecorator;
export declare function Description(desc: string): ClassDecorator;
export declare function Usage(usage: string): ClassDecorator;
export declare function OwnerOnly(): ClassDecorator;
export declare function NSFW(): ClassDecorator;
export declare function MinRole(role: string | Snowflake): ClassDecorator;
export declare function Hidden(): ClassDecorator;
