"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Set a name for the Command
 * @method Name
 * @param name {String} The name of the command
 * @returns {ClassDecorator}
 */
function Name(name) {
    return setMetaData('commandName', name);
}
exports.Name = Name;
/**
 * Only allow the command to be executed in a guild channel
 * @method GuildOnly
 * @returns {ClassDecorator}
 */
function Only(...types) {
    const x = {};
    for (const type of types) {
        x[type] = true;
    }
    return setMetaData('only', x);
}
exports.Only = Only;
/**
 * This extends the default command verifier and the given function runs
 * BEFORE any other part of the verifier runs
 * @method Verify
 * @param func {Function} The custom verifier part you want to use
 * @returns {ClassDecorator}
 */
function Verify(func) {
    return setMetaData('extendedVerify', func);
}
exports.Verify = Verify;
/**
 * Throttles commands to be only usable for x times per y seconds
 * @method Throttle
 * @param interval {Number} The time in seconds
 * @param times {Number} How often the command can be executed in X seconds
 * @param [all] {Boolean} Weather to throttle all (true) users or exclude the owner
 * @returns {ClassDecorator}
 */
function Throttle(interval, times, all = false) {
    return setMetaData('ratelimit', {
        all,
        times,
        timeout: interval
    });
}
exports.Throttle = Throttle;
/**
 * Set the aliases for a command
 * @param aliases {String[]} The aliases to apply
 * @returns {ClassDecorator}
 */
function Alias(...aliases) {
    return setMetaData('alias', aliases);
}
exports.Alias = Alias;
function UserPermissions(...perms) {
    return setMetaData('userPermissions', perms);
}
exports.UserPermissions = UserPermissions;
function Restricted(data) {
    return setMetaData('restricted', data);
}
exports.Restricted = Restricted;
function Description(desc) {
    return setMetaData('desc', desc);
}
exports.Description = Description;
function Usage(usage) {
    return setMetaData('usage', usage);
}
exports.Usage = Usage;
function OwnerOnly() {
    return setMetaData('ownerOnly', true);
}
exports.OwnerOnly = OwnerOnly;
function NSFW() {
    return setMetaData('nsfw', true);
}
exports.NSFW = NSFW;
function MinRole(role) {
    return setMetaData('minRole', role);
}
exports.MinRole = MinRole;
function Hidden() {
    return setMetaData('hidden', true);
}
exports.Hidden = Hidden;
/**
 * Private function to set the meta data for each command
 * @param key {string}
 * @param value {*}
 * @private
 * @returns {ClassDecorator}
 */
function setMetaData(key, value) {
    return function (target) {
        Object.defineProperty(target.prototype, key, {
            value,
            enumerable: false,
            configurable: true,
            writable: true
        });
        return target;
    };
}
//# sourceMappingURL=CommandDecorators.js.map