"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ArgumentMetadata_1 = require("../util/ArgumentMetadata");
/**
 * Get the arguments from the message content
 * @param [splitter] {RegExp}
 */
function Args(splitter = / +/g) {
    return function (target, key, index) {
        ArgumentMetadata_1.argumentStore.push({
            index,
            value: msg => msg.content.trim().split(splitter).slice(1),
            name: target.constructor.name.toLowerCase()
        });
    };
}
exports.Args = Args;
/**
 * Get the message Object
 */
function Msg() {
    return function (target, key, index) {
        ArgumentMetadata_1.argumentStore.push({
            index, value: msg => msg, name: target.constructor.name.toLowerCase()
        });
    };
}
exports.Msg = Msg;
/**
 * Get the roles of the message author
 */
function Roles() {
    return function (target, key, index) {
        ArgumentMetadata_1.argumentStore.push({
            index,
            value: msg => msg.guild ? msg.member.roles
                : console.warn('You can only use the @Roles decorator with the @GuildOnly command decorator.'),
            name: target.constructor.name.toLowerCase()
        });
    };
}
exports.Roles = Roles;
/**
 * Get a specific role from a user
 * @param role {String|Snowflake} The role ID or role name
 */
function Role(role) {
    return function (target, key, index) {
        ArgumentMetadata_1.argumentStore.push({
            index,
            value: (msg) => {
                if (!msg.member)
                    return null;
                return msg.member.roles.find(r => r.id === role || r.name.toLowerCase() === role.toLowerCase());
            },
            name: target.constructor.name.toLowerCase()
        });
    };
}
exports.Role = Role;
//# sourceMappingURL=PropertyDecorators.js.map