"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
const discord_js_1 = require("discord.js");
const ConfigError_1 = require("../../util/ConfigError");
const Listener_1 = require("../../util/Listener");
const Logger_1 = require("../../util/Logger");
const CommandLoader_1 = require("../command/CommandLoader");
const CommandRegistry_1 = require("../command/CommandRegistry");
const EventLoader_1 = require("../event/EventLoader");
const EventRegistry_1 = require("../event/EventRegistry");
/**
 * The SilentClient class
 * @extends Client
 * @class
 */
class SilentClient extends discord_js_1.Client {
    constructor(silent, config) {
        super(config);
        /**
         * @property {String} baseDir="dist/"
         * @public
         */
        this.baseDir = 'dist/';
        /**
         * @property {Boolean} baseCommands=true
         * @public
         */
        this.baseCommands = true;
        /**
         * @property {Boolean} rateLimitExceededError=true
         * @public
         */
        this.rateLimitExceededError = true;
        process.env.LOGLEVEL = silent.logLevel || 'WARN';
        if (silent.prefix)
            this.prefix = silent.prefix;
        if (silent.mentionPrefix !== undefined)
            this.mentionPrefix = silent.mentionPrefix;
        if (silent.baseDir)
            this.baseDir = silent.baseDir;
        if (silent.baseCommands !== undefined)
            this.baseCommands = silent.baseCommands;
        if (silent.commandNotFoundError)
            this.commandNotFoundError = silent.commandNotFoundError;
        if (silent.rateLimitExceededError !== undefined)
            this.rateLimitExceededError = silent.rateLimitExceededError;
        this._token = silent.token;
        this.owner = silent.owner;
        this.commandDir = silent.commandDir;
        this.eventDir = silent.eventDir;
        this.checkConfig();
        if (process.env.PRODUCTION) {
            this.commands = new CommandRegistry_1.CommandRegistry(this);
            const commandLoader = new CommandLoader_1.CommandLoader(this);
            commandLoader.loadFromPath(this.commandDir, false);
            if (this.baseDir)
                commandLoader.loadFromPath(null, true);
            this.events = new EventRegistry_1.EventRegistry(this);
            const eventLoader = new EventLoader_1.EventLoader(this);
            eventLoader.loadFromPath(this.eventDir);
        }
        const listener = new Listener_1.Listener(this, true);
        this.on('message', listener.handleMessageEvent.bind(listener));
    }
    /**
     * Connect to the Discord API
     */
    connect() {
        this._logger.debug('Trying to log in');
        this.login(this._token).then(() => {
            this._logger.debug('Successfully logged in');
        }).catch((err) => {
            this._logger.error(new ConfigError_1.ConfigError(err.message));
            process.exit(1);
        });
        return this;
    }
    /**
     * If multiple prefixes are set, this gets the default prefix.
     */
    // TODO: Option to explicitly set a default prefix
    get defaultPrefix() {
        if (Array.isArray(this.prefix))
            return this.prefix[0];
        if (!this.prefix && this.mentionPrefix)
            return `<@${this.user.id}>`;
        if (this.prefix)
            return this.prefix;
        return null;
    }
    /**
     * Checking the configurations
     * @throws ConfigError
     * @private
     */
    // TODO: Check all configs
    checkConfig() {
        this._logger.debug('Checking SilentConfig');
        if ((!this.prefix && !this.mentionPrefix) || (!Array.isArray(this.prefix) && typeof this.prefix !== 'string')) {
            this._logger.error(new ConfigError_1.ConfigError('A prefix or mention prefix has to be set.'));
            process.exit(1);
        }
        if (!this.owner || (!Array.isArray(this.owner) && typeof this.owner !== 'string')) {
            this._logger.error(new ConfigError_1.ConfigError('The owner property has to be set.'));
            process.exit(1);
        }
        if (!this.commandDir || typeof this.commandDir !== 'string') {
            this._logger.error(new ConfigError_1.ConfigError('The commandDir property has to bet set.'));
            process.exit(1);
        }
        if (!this.eventDir || typeof this.eventDir !== 'string') {
            this._logger.error(new ConfigError_1.ConfigError('The eventDir property has to be set'));
            process.exit(1);
        }
        if (!this._token || typeof this._token !== 'string') {
            this._logger.error(new ConfigError_1.ConfigError('The token has to be set.'));
            process.exit(1);
        }
        this._logger.debug('SilentConfig Check done');
    }
}
__decorate([
    Logger_1.logger()
], SilentClient.prototype, "_logger", void 0);
exports.SilentClient = SilentClient;
//# sourceMappingURL=SilentClient.js.map