"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
const glob = require("glob");
const path = require("path");
const Logger_1 = require("../../util/Logger");
class CommandLoader {
    constructor(client) {
        this.client = client;
        this.commands = client.commands;
    }
    loadFromPath(pathPattern, baseCommands = true) {
        this.logger.debug(`Starting to load commands from ${pathPattern}, including baseCommands: ${baseCommands}`);
        const resolvedPath = path.resolve(baseCommands ?
            `${__dirname}/base` :
            `${this.client.baseDir || ''}${pathPattern}`);
        const files = glob.sync(`${resolvedPath}/**/*.js`);
        this.logger.debug(`Found ${files.length} commands to load`);
        const loadedCommands = [];
        for (const file of files) {
            this.logger.debug(`Loading ${file}`);
            delete require.cache[require.resolve(file)];
            const loadedFile = require(file);
            const foundExport = Object.keys(loadedFile);
            if (foundExport.length === 1) {
                const foundClass = loadedFile[foundExport[0]];
                if (!foundClass) {
                    this.logger.warn(`File ${file} is in the commands directory but is not exporting a command`);
                    continue;
                }
                const foundInstance = new foundClass();
                // Defining the class name within the command class
                // This is used for the method decorators as they have no access
                // To the defined/custom command name set by a decorator
                Object.defineProperty(foundInstance, '_className', {
                    value: foundClass.name,
                    enumerable: true,
                    writable: false,
                    configurable: false
                });
                loadedCommands.push(foundInstance);
            }
            else
                this.logger.debug(`Could not find any export on file ${file}`);
            // TODO: Implement more than 1 export (type checking)
        }
        if (loadedCommands.length === 0)
            this.logger.error(new Error('Could not load any commands'));
        for (const command of loadedCommands) {
            this.logger.debug(`Registering command ${command.commandName}`);
            this.client.commands.registerInternalCommand(command);
        }
    }
}
__decorate([
    Logger_1.logger()
], CommandLoader.prototype, "logger", void 0);
exports.CommandLoader = CommandLoader;
//# sourceMappingURL=CommandLoader.js.map