"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const glob = require("glob");
const path = require("path");
class EventLoader {
    /**
     * @param client {SilentClient}
     * @constructor
     */
    constructor(client) {
        this.client = client;
        this.events = client.events;
    }
    /**
     * Load all files from a specific path
     * @param pathPattern {String}
     */
    loadFromPath(pathPattern) {
        const resolvedPath = path.resolve(`${this.client.baseDir || ''}${pathPattern}`);
        const files = glob.sync(`${resolvedPath}/**/*.js`);
        const loadedEvents = [];
        for (const file of files) {
            delete require.cache[require.resolve(file)];
            const loadedFile = require(file);
            const foundExport = Object.keys(loadedFile);
            if (foundExport.length === 1) {
                const foundClass = loadedFile[foundExport[0]];
                // TODO: Implement prototype checking, e.g. export can also be a class which is not an event
                if (!foundClass) {
                    console.warn(`File ${file} is in the event directory but is not exporting an event`);
                    continue;
                }
                const foundInstance = new foundClass();
                loadedEvents.push(foundInstance);
            }
            // TODO: Implement more than 1 export
        }
        for (const event of loadedEvents) {
            event._init(this.client);
            this.events.registerEvent(event);
        }
    }
}
exports.EventLoader = EventLoader;
//# sourceMappingURL=EventLoader.js.map